Utils
========

.. toctree::
  :hidden:
  :maxdepth: 1


.. automodule:: burdoc.utils
   :members:

.. contents::
    :depth: 2
    :local:
    :backlinks: top

Output Comparison
-----------------
.. automodule:: burdoc.utils.compare
   :members:

Image Manipulation
------------------
.. automodule::   burdoc.utils.image_manip
   :members:

Layout Graph
------------------
.. automodule:: burdoc.utils.layout_graph
   :members:

Logging
------------------
.. automodule:: burdoc.utils.logging
   :members:

Render Pages
------------------
.. automodule:: burdoc.utils.render_pages
   :members: